@@ -3,4 +3,4 @@ use Moo;
 use MooX::late;
 has bar => (is => 'ro', isa => 'Str|ArrayRef[Int|Num]|Int');
 
-Foo->new(bar => [1, "xyz", 3])
+Foo->new(bar => [1, '2o', 3])
